@@ -1,25 +1,20 @@
-from aiohttp import ClientSession, FormData
+from aiohttp import FormData
 from .ratelimit import RateLimiter
 
-
 class Request:
-    def __init__(self, http: RateLimiter, route: str, method: str, headers: dict = None, data: dict = None, files: dict = None):
-        self.route = 'https://im-a-dev.xyz/'
-        self.route += route
-        
+    def __init__(self, http: RateLimiter, route: str, method: str, headers: dict = {}, data: dict = {}, files: dict = {}):
+        self.route = f'https://im-a-dev.xyz/{route or ""}'
         self.method = method
         self.headers = headers
+        self.http = http
 
-        if data is not None:
+        if data:
             self.data = FormData()
             for k, v in data.items():
                 self.data.add_field(k, v)
 
-            if files is not None:
-                for k, v in files.items():
-                    self.data.add_field(k, v[1], filename=f'file.{v[0]}') # upload with correct file extension
-
-        self.http = http
+            if files:
+                self.data.add_field("image", files['bytes'], filename=f'file.{files["format"]}') # upload with correct file extension
         
     async def json(self):
         if self.method == 'GET':
